# Home

<p align="center">
    <a href="https://github.com/durandtibo/ghflowgen/actions">
        <img alt="CI" src="https://github.com/durandtibo/ghflowgen/workflows/CI/badge.svg">
    </a>
    <a href="https://github.com/durandtibo/ghflowgen/actions">
        <img alt="Nightly Tests" src="https://github.com/durandtibo/ghflowgen/workflows/Nightly%20Tests/badge.svg">
    </a>
    <a href="https://github.com/durandtibo/ghflowgen/actions">
        <img alt="Nightly Package Tests" src="https://github.com/durandtibo/ghflowgen/workflows/Nightly%20Package%20Tests/badge.svg">
    </a>
    <a href="https://codecov.io/gh/durandtibo/ghflowgen">
        <img alt="Codecov" src="https://codecov.io/gh/durandtibo/ghflowgen/branch/main/graph/badge.svg">
    </a>
    <br/>
    <a href="https://durandtibo.github.io/ghflowgen/">
        <img alt="Documentation" src="https://github.com/durandtibo/ghflowgen/workflows/Documentation%20(stable)/badge.svg">
    </a>
    <a href="https://durandtibo.github.io/ghflowgen/">
        <img alt="Documentation" src="https://github.com/durandtibo/ghflowgen/workflows/Documentation%20(unstable)/badge.svg">
    </a>
    <br/>
    <a href="https://github.com/psf/black">
        <img  alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg">
    </a>
    <a href="https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings">
        <img  alt="Doc style: google" src="https://img.shields.io/badge/%20style-google-3666d6.svg">
    </a>
    <a href="https://github.com/astral-sh/ruff">
        <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff" style="max-width:100%;">
    </a>
    <a href="https://github.com/guilatrova/tryceratops">
        <img  alt="Doc style: google" src="https://img.shields.io/badge/try%2Fexcept%20style-tryceratops%20%F0%9F%A6%96%E2%9C%A8-black">
    </a>
    <br/>
    <a href="https://pypi.org/project/ghflowgen/">
        <img alt="PYPI version" src="https://img.shields.io/pypi/v/ghflowgen">
    </a>
    <a href="https://pypi.org/project/ghflowgen/">
        <img alt="Python" src="https://img.shields.io/pypi/pyversions/ghflowgen.svg">
    </a>
    <a href="https://opensource.org/licenses/BSD-3-Clause">
        <img alt="BSD-3-Clause" src="https://img.shields.io/pypi/l/ghflowgen">
    </a>
    <br/>
    <a href="https://pepy.tech/project/ghflowgen">
        <img  alt="Downloads" src="https://static.pepy.tech/badge/ghflowgen">
    </a>
    <a href="https://pepy.tech/project/ghflowgen">
        <img  alt="Monthly downloads" src="https://static.pepy.tech/badge/ghflowgen/month">
    </a>
    <br/>
</p>

## Overview

TODO

## API stability

:warning: While `ghflowgen` is in development stage, no API is guaranteed to be stable from one
release to the next. In fact, it is very likely that the API will change multiple times before a
stable 1.0.0 release. In practice, this means that upgrading `ghflowgen` to a new version will
possibly break any code that was using the old version of `ghflowgen`.

## License

`ghflowgen` is licensed under BSD 3-Clause "New" or "Revised" license available
in [LICENSE](https://github.com/durandtibo/ghflowgen/blob/main/LICENSE) file.
